@@ -32,7 +32,9 @@ using namespace KCalCore;
 // Maximum number of intervals to process
 const int LOOP_LIMIT = 10000;
 
+#ifndef NDEBUG
 static QString dumpTime(const KDateTime &dt);     // for debugging
+#endif
 
 /*=========================================================================
 =                                                                         =
@@ -271,7 +273,6 @@ public:
     bool matches(const QDate &dt, RecurrenceRule::PeriodType type) const;
     bool matches(const KDateTime &dt, RecurrenceRule::PeriodType type) const;
     bool merge(const Constraint &interval);
-    bool isConsistent() const;
     bool isConsistent(RecurrenceRule::PeriodType period) const;
     bool increase(RecurrenceRule::PeriodType type, int freq);
     KDateTime intervalDateTime(RecurrenceRule::PeriodType type) const;
@@ -707,7 +708,7 @@ bool Constraint::readDateTime(const KDateTime &dt, RecurrenceRule::PeriodType ty
  **************************************************************************/
 
 //@cond PRIVATE
-class KCalCore::RecurrenceRule::Private
+class Q_DECL_HIDDEN KCalCore::RecurrenceRule::Private
 {
 public:
     Private(RecurrenceRule *parent)
